@@ -1,4 +1,4 @@
-# $Id: ZapListings.pm,v 1.64 2003/09/27 18:21:03 jveldhuis Exp $
+# $Id: ZapListings.pm,v 1.70 2003/11/02 22:43:25 epaepa Exp $
 
 #
 # Special thanks to Stephen Bain for helping me play catch-up with
@@ -152,7 +152,7 @@ sub new
 				  env_proxy => 1,
 				  timeout => 180);
     bless ($self, $class);
-    $self->agent('xmltv/0.5.19');
+    $self->agent('xmltv/0.5.20');
     return $self;
 }
 
@@ -1079,7 +1079,7 @@ sub getChannelList($$)
 
 	my $result=new XMLTV::ZapListings::ScrapeRow()->parse($row);
 	if ( !$result ) {
-	    warn("ignoing html table row that failed to parse:'$row'");
+	    warn("ignoring html table row that failed to parse:'$row'");
 	    next;
 	}
 
@@ -1322,11 +1322,13 @@ sub scrapehtml($$$)
 			  Aboriginal
 			  Arabic
 			  Armenian
+			  Bengali
 			  Cambodian
 			  Cantonese
 			  Chinese
 			  Colonial
 			  Cree
+			  Dari
 			  Dene
 			  Diwlai
 			  English
@@ -1351,23 +1353,29 @@ sub scrapehtml($$$)
 			  Khmer
 			  Korean
 			  Mandarin
+			  Macedonian
 			  Mi'kmaq
 			  Mohawk
 			  Musgamaw
 			  Oji
 			  Ojibwa
 			  Panjabi
+			  Persian
 			  Polish
 			  Portuguese
 			  Punjabi
+			  Pushto
 			  Quechuan
 			  Romanian
 			  Russian
+			  Sinhalese
+			  Somali
 			  Spanish
 			  Swedish
 			  Tagalog
 			  Tamil
 			  Tlingit
+			  Turkish
 			  Ukrainian
 			  Urdu
 			  Vietnamese
@@ -1414,7 +1422,7 @@ sub scrapehtml($$$)
 	# run it through our row scaper that separates out the html
 	my $result=new XMLTV::ZapListings::ScrapeRow()->parse($row);
 	if ( !$result ) {
-	    warn("ignoing html table row that failed to parse:'$row'");
+	    warn("ignoring html table row that failed to parse:'$row'");
 	    next;
 	}
 
@@ -2091,10 +2099,11 @@ sub readSchedule($$$$$)
 
     my $content;
     my $cacheFile;
+    my $cacheDir=$self->{CacheDir};
 
-    if ( -f "urldata/$stationid/content-$month-$day-$year.html" &&
-	 open(FD, "< urldata/$stationid/content-$month-$day-$year.html") ) {
-	main::statusMessage("cache enabled, reading urldata/$stationid/content-$month-$day-$year.html..\n");
+    if ( defined($cacheDir) && -f "$cacheDir/$stationid/content-$month-$day-$year.html" &&
+	 open(FD, "< $cacheDir/$stationid/content-$month-$day-$year.html") ) {
+	main::statusMessage("cache enabled, reading $cacheDir/$stationid/content-$month-$day-$year.html..\n");
 	my $s=$/;
 	undef($/);
 	$content=<FD>;
@@ -2122,8 +2131,8 @@ sub readSchedule($$$$$)
 	# looks like some requests require two identical calls since
 	# the zap2it server gives us a cookie that works with the second
 	# attempt after the first fails
-    warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
-    if ( !($res->is_success || $res->code eq '500') || $res->content()=~m/your session has timed out/i ) {
+	warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
+	if ( !($res->is_success || $res->code eq '500') || $res->content()=~m/your session has timed out/i ) {
 	    # again, but manditory sleep(5) between retries
 	    sleep(5);
 	    $res=&doRequest($self->{ua}, $req, $self->{Debug});
@@ -2146,10 +2155,10 @@ sub readSchedule($$$$$)
 	   warn("ERROR: $err\n");
 	   return(-1);
         }
-	if ( -d "urldata" ) {
-	    $cacheFile="urldata/$stationid/content-$month-$day-$year.html";
-	    if ( ! -d "urldata/$stationid" ) {
-		mkdir("urldata/$stationid", 0775) || warn "failed to create dir urldata/$stationid:$!";
+	if ( defined($cacheDir) && -d $cacheDir ) {
+	    $cacheFile="$cacheDir/$stationid/content-$month-$day-$year.html";
+	    if ( ! -d "$cacheDir/$stationid" ) {
+		mkdir("$cacheDir/$stationid", 0775) || warn "failed to create dir $cacheDir/$stationid:$!";
 	    }
 	    if ( open(FD, "> $cacheFile") ) {
 		print FD $content;
@@ -2188,8 +2197,8 @@ sub readSchedule($$$$$)
       main::statusMessage("cache enabled, writing $cacheFile..\n");
     }
 
-  main::statusMessage("Day $year-$month-$day schedule for station $station_desc has:".
-		      scalar(@{$self->{Programs}})." programs\n");
+    main::statusMessage("Day $year-$month-$day schedule for station $station_desc has:".
+			scalar(@{$self->{Programs}})." programs\n");
     
     return(scalar(@{$self->{Programs}}));
 }
